import { DatePipe } from '@angular/common';
import { Component, OnInit } from '@angular/core';
import { ColDef } from 'ag-grid-community';
import { AccompanimentTypes } from '../../../form/orientation-form-view/enums/orientation.enums';
import { IOrientation } from '../../../form/orientation-form-view/interfaces/orientation.interface';
import { Status, StatusKey } from '../../../profile/dashboard/orientation.enum';
import { AdminService } from '../../services/admin.service';

@Component({
  selector: 'app-admin-manage-orientations',
  templateUrl: './manage-orientations.component.html',
  styleUrls: ['../../admin.scss'],
})
export class ManageOrientationsComponent implements OnInit {
  constructor(
    private adminService: AdminService,
    private datePipe: DatePipe,
  ) {}
  public orientations: IOrientation[];

  public defaultColDef: ColDef = {
    flex: 1,
    resizable: true,
    sortable: true,
  };

  public columnsDefsOrientation: ColDef[] = [
    {
      headerName: 'Status',
      field: 'status',
      valueGetter: (params): string => {
        const statusSlug = params.data.status as StatusKey;
        return Status[statusSlug]?.label || statusSlug;
      },
    },
    {
      headerName: 'Type',
      field: 'type',
    },
    {
      headerName: 'Catégorie',
      field: 'accompanimentType',
      valueGetter: (params): string => {
        const accompanimentTypeKey = params.data.accompanimentType;
        return AccompanimentTypes[accompanimentTypeKey as keyof typeof AccompanimentTypes] || accompanimentTypeKey;
      },
    },
    {
      headerName: 'Date de création',
      field: 'createdAt',
      valueFormatter: (params): string => this.datePipe.transform(params.value, 'mediumDate'),
    },
    {
      headerName: 'Structure(s) choisie(s)',
      field: 'structureChoice',
      valueGetter: (params): string => {
        const structureChoices = params.data.structureChoice;
        return Array.isArray(structureChoices) ? structureChoices.map((choice) => choice.structureName).join(', ') : '';
      },
    },
    {
      headerName: 'Accompagnant numérique',
      field: 'socialWorker',
      valueGetter: (params): string => {
        const socialWorker = params.data.socialWorker;
        return socialWorker ? `${socialWorker.name} ${socialWorker.surname}` : '';
      },
    },
    {
      headerName: 'Orienteur',
      field: 'orientator',
      valueGetter: (params): string => {
        const orientator = params.data.orientator;
        return orientator ? `${orientator.name} ${orientator.surname}` : '';
      },
    },
    {
      headerName: 'Structure orientatrice',
      field: 'structureOrientator',
      valueGetter: (params): string => {
        const structOrientator = params.data.structureOrientator;
        return structOrientator ? `${structOrientator.structureName}` : '';
      },
    },
    {
      headerName: 'Besoin',
      field: 'need',
    },
  ];

  ngOnInit(): void {
    this.adminService.getAllOrientations().subscribe((orientations) => {
      this.orientations = orientations;
    });
  }
}
