import { Component, Input, OnInit } from '@angular/core';
import { Structure } from '../../../../models/structure.model';
import { AccessModality } from '../../../../structure-list/enum/access-modality.enum';
import { SearchService } from '../../../../structure-list/services/search.service';
import { FreeWorkShopLabels } from '../../../../structure/enums/freeWorkshop.enum';
import { Utils } from '../../../../utils/utils';

@Component({
  selector: 'app-detailed-structure-card',
  templateUrl: './detailed-structure-card.component.html',
  styleUrls: ['./detailed-structure-card.component.scss'],
})
export class DetailedStructureCardComponent implements OnInit {
  @Input({ required: true }) structure: Structure;
  public hasTclInfo = true;
  public FreeWorkShopLabels = FreeWorkShopLabels;

  constructor(
    private searchService: SearchService,
    private utils: Utils,
  ) {}

  ngOnInit(): void {
    this.searchService.getCategories().subscribe((categories) => {
      this.utils.setServiceCategories(categories, this.structure);
    });
  }

  public showServices(): boolean {
    return (
      this.structure.categories.onlineProcedures.length > 0 ||
      this.structure.categories.baseSkills.length > 0 ||
      this.structure.categories.advancedSkills.length > 0 ||
      this.structure.hasEquipments()
    );
  }

  public getAccessLabel(name: string): string {
    return this.utils.getAccessLabel(name as AccessModality);
  }

  public getFreeWorkShop(): string {
    return this.structure.categoriesDisplay?.freeWorkShop[0].displayText.toLowerCase();
  }
}
