import { Component, Input } from '@angular/core';
import { Router } from '@angular/router';
import { OrientationService } from '../../../services/orientation.service';

@Component({
  selector: 'app-orientations-table',
  templateUrl: './orientations-table.component.html',
  styleUrls: ['./orientations-table.component.scss'],
})
export class OrientationsTableComponent {
  constructor(
    public orientationService: OrientationService,
    private router: Router,
  ) {}

  @Input() orientations: any[];
  @Input() from: string;
  @Input() history?: boolean;

  public isUrgent(orientation): boolean {
    return (
      this.orientationService.daysAgo(orientation.updatedAt) > 14 &&
      this.from !== 'myOrientations' &&
      (orientation.status === 'new' || orientation.status === 'waiting')
    );
  }

  public isNew(orientation): boolean {
    return !this.isUrgent(orientation) && orientation.status === 'new' && this.from !== 'myOrientations';
  }

  public navigateToDetails(event: Event, orientationId: string): void {
    event.preventDefault();
    this.router.navigate(['/profil/details-orientation', orientationId], {
      state: { from: this.from },
    });
  }
}
